==> haskell-bencode-0.6.1.1-219-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bencode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bencode
version:              0.6.1.1
visibility:           public
id:                   bencode-0.6.1.1-G14rW3J4HCe5SyjC6saXsT
key:                  bencode-0.6.1.1-G14rW3J4HCe5SyjC6saXsT
license:              BSD-3-Clause
copyright:
    (c) 2005-2009, David Himmelstrup,
    (c) 2006 Lemmih <lemmih@gmail.com>,
    (c) 2005 Jesper Louis Andersen <jlouis@mongers.org>

maintainer:           Peter Simons <simons@cryp.to>
author:
    Lemmih <lemmih@gmail.com>,
    Jesper Louis Andersen <jlouis@mongers.org>,
    Christopher Reichert <creichert07@gmail.com>

synopsis:             Parsers and printers for bencoded data.
description:
    Parsers and printers for bencoded data. Bencode (pronounced like B
    encode) is the encoding used by the peer-to-peer file sharing system
    BitTorrent for storing and transmitting loosely structured data.

category:             Text
abi:                  25db552d5bb0fc96a2f9fc21c43fe4d7
exposed:              True
exposed-modules:
    Data.BEncode Data.BEncode.Lexer Data.BEncode.Parser
    Data.BEncode.Reader

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bencode-0.6.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bencode-0.6.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bencode-0.6.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bencode
hs-libraries:         HSbencode-0.6.1.1-G14rW3J4HCe5SyjC6saXsT
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    parsec-3.1.16.1 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-bencode/html/bencode.haddock
haddock-html:         /usr/share/doc/haskell-bencode/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bencode-0.6.1.1-225-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bencode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bencode
version:              0.6.1.1
visibility:           public
id:                   bencode-0.6.1.1-64jeOei4q5kDBGUHk70li
key:                  bencode-0.6.1.1-64jeOei4q5kDBGUHk70li
license:              BSD-3-Clause
copyright:
    (c) 2005-2009, David Himmelstrup,
    (c) 2006 Lemmih <lemmih@gmail.com>,
    (c) 2005 Jesper Louis Andersen <jlouis@mongers.org>

maintainer:           Peter Simons <simons@cryp.to>
author:
    Lemmih <lemmih@gmail.com>,
    Jesper Louis Andersen <jlouis@mongers.org>,
    Christopher Reichert <creichert07@gmail.com>

synopsis:             Parsers and printers for bencoded data.
description:
    Parsers and printers for bencoded data. Bencode (pronounced like B
    encode) is the encoding used by the peer-to-peer file sharing system
    BitTorrent for storing and transmitting loosely structured data.

category:             Text
abi:                  38c01d28727d1b558f61c9d541251a7a
exposed:              True
exposed-modules:
    Data.BEncode Data.BEncode.Lexer Data.BEncode.Parser
    Data.BEncode.Reader

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bencode-0.6.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bencode-0.6.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bencode-0.6.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bencode
hs-libraries:         HSbencode-0.6.1.1-64jeOei4q5kDBGUHk70li
depends:
    base-4.17.2.1 binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    parsec-3.1.16.1 transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ

haddock-interfaces:   /usr/share/doc/haskell-bencode/html/bencode.haddock
haddock-html:         /usr/share/doc/haskell-bencode/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
